import { DynamoDBClient } from "@aws-sdk/client-dynamodb";
import { DynamoDBDocumentClient, PutCommand } from "@aws-sdk/lib-dynamodb";
import DatabaseClient from "./database-client";

describe("DatabaseClient", () => {
    let dynamoDbClient: DynamoDBDocumentClient;
    let databaseClient: DatabaseClient;

    beforeEach(() => {
        dynamoDbClient = DynamoDBDocumentClient.from(new DynamoDBClient({
            endpoint: 'http://127.0.0.1:8000',
            region: 'local-env',
            credentials: {
                accessKeyId: 'test-access-key-id',
                secretAccessKey: 'test-secret-access-key',
            },
        }));
        databaseClient = new DatabaseClient(dynamoDbClient);
    });

    it("should list tables", async () => {
        const result = await databaseClient.readTables();

        expect(result).toEqual(["example-table-1", "example-table-2"]);
    });

    it("should scan table", async () => {
        const insertItem = async (id: string, otherValue: string) => {
            await dynamoDbClient.send(new PutCommand({
                TableName: "example-table-1",
                Item: { id, otherValue }
            }));
        }
        await Promise.all([
            insertItem("1", "Item 1"),
            insertItem("2", "Item 2"),
            insertItem("3", "Item 3")
        ]);

        const result = await databaseClient.scanTable("example-table-1", 2);

        expect(result).toHaveLength(3);
        expect(result).toContainEqual({ id: "1", otherValue: "Item 1" });
        expect(result).toContainEqual({ id: "2", otherValue: "Item 2" });
        expect(result).toContainEqual({ id: "3", otherValue: "Item 3" });
    });
});
