import { DynamoDBClient, ListTablesCommand } from "@aws-sdk/client-dynamodb";
import { DynamoDBDocumentClient, ScanCommand } from "@aws-sdk/lib-dynamodb";
import { mockClient } from 'aws-sdk-client-mock';
import DatabaseClient from "./database-client";

describe("DatabaseClient", () => {
    let dynamoDbClient: DynamoDBDocumentClient;
    let databaseClient: DatabaseClient;

    beforeEach(() => {
        dynamoDbClient = DynamoDBDocumentClient.from(new DynamoDBClient({}));
        databaseClient = new DatabaseClient(dynamoDbClient);
    });

    it("should list tables", async () => {
        const mockDynamoDbClient = mockClient(dynamoDbClient);
        mockDynamoDbClient
            .on(ListTablesCommand)
            .resolvesOnce({
                TableNames: ["example-table-1", "example-table-2"]
            });

        const result = await databaseClient.readTables();

        expect(result).toEqual(["example-table-1", "example-table-2"]);
    });

    it("should scan table", async () => {
        const mockDynamoDbClient = mockClient(dynamoDbClient);
        mockDynamoDbClient
            .on(ScanCommand)
            .resolvesOnce({
                Items: [
                    { id: "1", otherValue: "Item 1" },
                    { id: "2", otherValue: "Item 2" },
                ],
                LastEvaluatedKey: { id: "2" },
            })
            .resolvesOnce({
                Items: [
                    { id: "3", otherValue: "Item 3" },
                ]
            });

        const result = await databaseClient.scanTable("example-table-1", 2);

        expect(result).toHaveLength(3);
        expect(result).toContainEqual({ id: "1", otherValue: "Item 1" });
        expect(result).toContainEqual({ id: "2", otherValue: "Item 2" });
        expect(result).toContainEqual({ id: "3", otherValue: "Item 3" });
    });
});
