import { ListTablesCommand, ScanCommand } from "@aws-sdk/client-dynamodb";
import { DynamoDBDocumentClient, paginateScan } from "@aws-sdk/lib-dynamodb";

export default class DatabaseClient {
    constructor(private readonly client: DynamoDBDocumentClient) {}

    public async readTables(): Promise<string[]> {
        const command = new ListTablesCommand({});
    
        const results = await this.client.send(command);
    
        return results.TableNames!;
    }

    public async scanTable(tableName: string, pageSize: number): Promise<unknown[]> {
        const paginator = paginateScan({ client: this.client, pageSize }, { TableName: tableName });

        const results = [];
        let pageNumber = 0;
        for await (const page of paginator) {
            console.log("Processing page %s", ++pageNumber);
            results.push(...page.Items!);
        }

        console.log("Processed %s pages", pageNumber);

        return results;
    }
}
